import React, { ReactNode } from 'react';
import { ImageProps as OriginImageProps, ImageSourcePropType } from 'react-native';
import { TColor } from '@react-native-cask-ui/theme';
import { $Diff } from 'utility-types';
export interface ImageProps extends $Diff<OriginImageProps, {
    source: ImageSourcePropType;
}> {
    ImageRenderer?: ReactNode;
    /**
     * The variant to use.
     */
    variant?: string;
    /**
     * The image element or remote url.
     */
    source: ImageSourcePropType;
    /**
     * If `true`, the image size will fill the parent container.
     */
    fill?: boolean;
    /**
     * The width of the image. If `undefined`, the image width will equal to the parent container.
     */
    width?: number;
    /**
     * The height of the image. If `undefined`, the image height will equal to the parent container.
     */
    height?: number;
    /**
     * The default width of the placeholder.
     */
    placeholderWidth?: number;
    /**
     * The default height of the placeholder.
     */
    placeholderHeight?: number;
    /**
     * The type of placeholder.
     */
    placeholderType?: 'loader' | 'spinner' | 'progress';
    /**
     * If `true`, the image will keep trying to load the source.
     */
    retryable?: boolean;
    /**
     * The primary color of the loader type placeholder.
     */
    loaderPrimaryColor?: TColor;
    /**
     * The secondary color of the loader type placeholder.
     */
    loaderSecondaryColor?: TColor;
    /**
     * The color of the progress type placeholder.
     */
    progressColor?: TColor;
}
declare const Image: React.FC<ImageProps>;
export default Image;
