import React, { useMemo } from 'react';
import { StyleSheet, View, StatusBar } from 'react-native';
import SafeAreaView from 'react-native-safe-area-view';
import { useOverride, useMemoStyles } from '@react-native-cask-ui/theme';
const defaultStyles = StyleSheet.create({
    root: {
        flex: 1,
        overflow: 'hidden',
    },
    safeArea: {
        flex: 1,
    },
    inner: {
        flex: 1,
    },
    padding: {
        paddingVertical: 16,
        paddingHorizontal: 24,
    },
});
export default React.memo(props => {
    const { props: overridedProps, styles } = useOverride('Screen', props);
    const { padding, topSafe, bottomSafe, statusBar: statusBarProps, children } = overridedProps;
    const finalStyle = useMemoStyles([defaultStyles.root, styles.root]);
    const finalSafeAreaStyle = useMemoStyles([defaultStyles.safeArea, styles.safeArea]);
    const finalInnerStyle = useMemoStyles([defaultStyles.inner, styles.inner, padding ? defaultStyles.padding : {}]);
    const forceInset = useMemo(() => {
        const top = topSafe ? 'always' : 'never';
        const bottom = bottomSafe ? 'always' : 'never';
        return { top, bottom };
    }, [topSafe, bottomSafe]);
    return (<View style={finalStyle}>
      <SafeAreaView forceInset={forceInset} style={finalSafeAreaStyle}>
        <View style={finalInnerStyle}>{children}</View>
      </SafeAreaView>
      <StatusBar {...statusBarProps}/>
    </View>);
});
